View source: R/cox.stuart.test.R
| cox.stuart.test | R Documentation |
Cox-Stuart test for trend analysis The Cox-Stuart test is defined as a little powerful test (power equal to 0.78), but very robust for the trend analysis. It is therefore applicable to a wide variety of situations, to get an idea of the evolution of values obtained. The proposed method is based on the binomial distribution. This function was written by Tommaso Martino<todoslogos@gmail.com>
cox.stuart.test(x)
x |
A numeric vector |
A list with class "htest"
customers = c(5, 9, 12, 18, 17, 16, 19, 20, 4, 3, 18, 16, 17, 15, 14)
cox.stuart.test(customers)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.